iotools.underscore_delimited_lowercase_to_uppercamelcase
========================================================

.. autofunction:: abjad.tools.iotools.underscore_delimited_lowercase_to_uppercamelcase.underscore_delimited_lowercase_to_uppercamelcase
